@@ -341,7 +341,7 @@ class MutationRoot:
         firmware_arg = parse_arg("firmware", firmware)
         stored_notifications_arg = parse_arg(
             "storedNotifications", stored_notifications)
-        res = self.client.mutation('mutation{createThing(%s%s%s%s){id}}' % (
+        res = self.client.mutation('mutation{createThing(%s%s%s){id}}' % (
             type_arg, firmware_arg, stored_notifications_arg))["createThing"]
 
         # FIXME: if we choose to keep the createThingPayload implement it here
